#!/usr/bin/python

import intake
import unittest
import pandas as pd

class TestCatalog(unittest.TestCase):
    def test_load_catalog(self):
        col_url = "/home/k/k204210/intake-esm/esm-collections/disk-access/dkrz_cmip6_disk.json"
        testdf=pd.read_csv("/home/k/k204210/intake-esm/catalogs/dkrz_cmip6_disk.csv.gz")
        
        self.assertTrue(intake.open_esm_datastore(testdf,
                                                  esmcol_data=col_url),
                        msg="Intake could not load catalog '{0}'".format(col_url))
    def test_load_cmipScenario(self):
        col_url = "/home/k/k204210/intake-esm/esm-collections/disk-access/dkrz_cmip6_disk.json"
        testdf=pd.read_csv("/home/k/k204210/intake-esm/catalogs/dkrz_cmip6_disk.csv.gz")
        col = intake.open_esm_datastore(testdf,esmcol_data=col_url)
        cat = col.search(source_id=["MPI-ESM1-2-HR", "AWI-CM-1-2-HR"], activity_id=["CMIP", "ScenarioMIP"])
        noOfExps = cat.unique(columns=["experiment_id"])["experiment_id"]["count"]
        self.assertTrue(noOfExps >= 9,
                       msg="Number of experiments in intake catalog for DICAD-Sources and"
                       "CMIP-Experiments is lower than 9.")
    def test_len_catalog(self):
        col_url = "/home/k/k204210/intake-esm/esm-collections/disk-access/dkrz_cmip6_disk.json"
        testdf=pd.read_csv("/home/k/k204210/intake-esm/catalogs/dkrz_cmip6_disk.csv.gz")
        col = intake.open_esm_datastore(testdf,esmcol_data=col_url)
        len_new = len(col.df)
        col_url_old="/home/k/k204210/intake-esm/tests/dkrz_cmip6_disk_old.json"
        col_old=intake.open_esm_datastore(col_url_old)
        len_old = len(col.df)
        self.assertTrue(len_new >= len_old,
                       msg="New cataolg file contains less datasets than the old one.")
        
if __name__ == '__main__':
    unittest.main()
